import { type CompilableTransactionMessage, type ITransactionMessageWithFeePayer, type TransactionMessage, type TransactionMessageWithBlockhashLifetime } from "@solana/transaction-messages";
import type { GetLatestBlockhashApi, Rpc, SimulateTransactionApi } from "@solana/rpc";
type PrepareCompilableTransactionMessage = CompilableTransactionMessage | (ITransactionMessageWithFeePayer & TransactionMessage);
export type PrepareTransactionConfig<TMessage extends PrepareCompilableTransactionMessage> = {
    /**
     * Transaction to prepare for sending to the blockchain
     */
    transaction: TMessage;
    /**
     * RPC client capable of simulating transactions and getting the latest blockhash
     **/
    rpc: Rpc<SimulateTransactionApi & GetLatestBlockhashApi>;
    /**
     * Multiplier applied to the simulated compute unit value obtained from simulation
     *
     * Default: `1.1`
     **/
    computeUnitLimitMultiplier?: number;
    /**
     * Whether or not you wish to force reset the compute unit limit value (if one is already set)
     * using the simulation response and `computeUnitLimitMultiplier`
     **/
    computeUnitLimitReset?: boolean;
    /**
     * Whether or not you wish to force reset the latest blockhash (if one is already set)
     *
     * Default: `true`
     **/
    blockhashReset?: boolean;
};
/**
 * Prepare a Transaction to be signed and sent to the network. Including:
 * - setting a compute unit limit (if not already set)
 * - fetching the latest blockhash (if not already set)
 * - (optional) simulating and resetting the compute unit limit
 * - (optional) resetting latest blockhash to the most recent
 */
export declare function prepareTransaction<TMessage extends PrepareCompilableTransactionMessage>(config: PrepareTransactionConfig<TMessage>): Promise<TMessage & Readonly<{
    instructions: readonly import("@solana/instructions").IInstruction<string, readonly (import("@solana/instructions").IAccountLookupMeta<string, string> | import("@solana/instructions").IAccountMeta<string>)[]>[];
    version: import("@solana/transaction-messages").TransactionVersion;
}> & TransactionMessageWithBlockhashLifetime>;
export {};
//# sourceMappingURL=prepare-transaction.d.ts.map